@@ -1,23 +1,23 @@
 # A collection of functions which operate on DLM data object (class
-# DLM_data) which is used as input object for the management
+# Data) which is used as input object for the management
 # procedures.
 
 # These functions are used either internally in the MSE (runMSE.r) or
 # used manually to apply a MP (or MPs) to a particular data object.
 
-DLMdiag <- function(DLM_data, command = "available", reps = 5, timelimit = 1) {
-  funcs1 <- c(avail("DLM_output"), avail("DLM_input"))
+DLMdiag <- function(Data, command = "available", reps = 5, timelimit = 1) {
+  funcs1 <- c(avail("Output"), avail("Input"))
   good <- rep(TRUE, length(funcs1))
   report <- rep("Worked fine", length(funcs1))
   test <- new("list")
   timey <- new("list")
   options(show.error.messages = FALSE)
   for (y in 1:length(funcs1)) {
-    if (class(match.fun(funcs1[y])) == "DLM_output") {
+    if (class(match.fun(funcs1[y])) == "Output") {
       time1 <- Sys.time()
       suppressWarnings({
         setTimeLimit(timelimit * 1.5)
-        test[[y]] <- try(do.call(funcs1[y], list(x = 1, DLM_data = DLM_data, 
+        test[[y]] <- try(do.call(funcs1[y], list(x = 1, Data = Data, 
           reps = 5)), silent = T)
         if (class(test[[y]]) == "list") 
           test[[y]] <- test[[y]][[1]]
@@ -27,7 +27,7 @@ DLMdiag <- function(DLM_data, command = "available", reps = 5, timelimit = 1) {
       time1 <- Sys.time()
       suppressWarnings({
         setTimeLimit(timelimit * 1.5)
-        test[[y]] <- try(do.call(funcs1[y], list(x = 1, DLM_data = DLM_data)), 
+        test[[y]] <- try(do.call(funcs1[y], list(x = 1, Data = Data)), 
           silent = T)
         setTimeLimit(Inf)
       })
@@ -52,26 +52,26 @@ DLMdiag <- function(DLM_data, command = "available", reps = 5, timelimit = 1) {
   if (command == "not available") 
     return(cbind(funcs1[!good], report[!good]))
   if (command == "needed") 
-    return(needed(DLM_data, funcs = funcs1[!good]))
+    return(needed(Data, funcs = funcs1[!good]))
 }
 
-needed <- function(DLM_data, funcs = NA) {
+needed <- function(Data, funcs = NA) {
   if (is.na(funcs[1])) 
-    funcs <- avail("DLM_output")
-  slots <- slotNames("DLM_data")
-  rr <- try(slot(DLM_data, "Misc"), silent = TRUE)
+    funcs <- avail("Output")
+  slots <- slotNames("Data")
+  rr <- try(slot(Data, "Misc"), silent = TRUE)
   if (class(rr) == "try-error") 
-    DLM_data@Misc <- list()
+    Data@Misc <- list()
   
-  slotnams <- paste("DLM_data@", slotNames(DLM_data), sep = "")
+  slotnams <- paste("Data@", slotNames(Data), sep = "")
   repp <- rep("", length(funcs))
-  DLM_data@Misc <- list()
+  Data@Misc <- list()
   for (i in 1:length(funcs)) {
     temp <- format(match.fun(funcs[i]))
     temp <- paste(temp[1:(length(temp))], collapse = " ")
     rec <- ""
     for (j in 1:length(slotnams)) {
-      if (grepl(slotnams[j], temp) & NAor0(slot(DLM_data, slots[j]))) 
+      if (grepl(slotnams[j], temp) & NAor0(slot(Data, slots[j]))) 
         rec <- c(rec, slots[j])
     }
     repp[i] <- paste(funcs[i], ": ", paste(rec[2:length(rec)], collapse = ", "), 
@@ -80,20 +80,20 @@ needed <- function(DLM_data, funcs = NA) {
   repp
 }
 
-parallelMPs <- function(x, DLM_data, reps, MPs, ss) sapply(ss, MPs[x], 
-  DLM_data, reps = reps)
+parallelMPs <- function(x, Data, reps, MPs, ss) sapply(ss, MPs[x], 
+  Data, reps = reps)
 
 #' Make stochastic variables certain for only one rep
 #' 
 #' As title.
 #'
-#' @param DLM_data An object of class DLM_data that has been run though TAC()
+#' @param Data An object of class Data that has been run though TAC()
 #' @author T. Carruthers
 #' @keywords internal 
 #' @export OneRep
-OneRep <- function(DLM_data) {
-  DLM_data@CV_Cat = DLM_data@CV_Dt = DLM_data@CV_AvC = DLM_data@CV_Ind = DLM_data@CV_Mort = DLM_data@CV_FMSY_M = DLM_data@CV_BMSY_B0 = DLM_data@CV_Cref = DLM_data@CV_Bref = DLM_data@CV_Iref = DLM_data@CV_Rec = DLM_data@CV_Dep = DLM_data@CV_Abun = DLM_data@CV_L50 = DLM_data@CV_vbK = DLM_data@CV_vbLinf = DLM_data@CV_vbt0 = DLM_data@CV_LFC = DLM_data@CV_LFS = DLM_data@CV_wla = DLM_data@CV_wlb = DLM_data@CV_steep = DLM_data@sigmaL = tiny
-  DLM_data
+OneRep <- function(Data) {
+  Data@CV_Cat = Data@CV_Dt = Data@CV_AvC = Data@CV_Ind = Data@CV_Mort = Data@CV_FMSY_M = Data@CV_BMSY_B0 = Data@CV_Cref = Data@CV_Bref = Data@CV_Iref = Data@CV_Rec = Data@CV_Dep = Data@CV_Abun = Data@CV_L50 = Data@CV_vbK = Data@CV_vbLinf = Data@CV_vbt0 = Data@CV_LFC = Data@CV_LFS = Data@CV_wla = Data@CV_wlb = Data@CV_steep = Data@sigmaL = tiny
+  Data
 }
 
 
@@ -102,54 +102,54 @@ OneRep <- function(DLM_data) {
 #' As title.
 #' 
 #' 
-#' @usage plotOFL(DLM_data,xlims=NA,perc=0.5)
-#' @param DLM_data An object of class DLM_data that has been run though TAC()
+#' @usage plotOFL(Data,xlims=NA,perc=0.5)
+#' @param Data An object of class Data that has been run though TAC()
 #' @param xlims x axis limits
 #' @param perc The percentile of the OFL distribution to be plotted
 #' @return A table of performance metrics.
 #' @author T. Carruthers
 #' @export plotOFL
-plotOFL <- function(DLM_data, xlims = NA, perc = 0.5) {
+plotOFL <- function(Data, xlims = NA, perc = 0.5) {
   
   cols <- rep(c("black", "red", "green", "blue", "orange", "brown", "purple", 
     "dark grey", "violet", "dark red", "pink", "dark blue", "grey"), 
     4)
   ltys <- rep(1:4, each = 13)
   
-  funcs <- DLM_data@MPs
+  funcs <- Data@MPs
   nMPs <- length(funcs)
   
   if (is.na(xlims[1]) | length(xlims) != 2) {
-    xlims <- quantile(DLM_data@TAC, c(0.005, 0.9), na.rm = T)
+    xlims <- quantile(Data@TAC, c(0.005, 0.9), na.rm = T)
     if (xlims[1] < 0) 
       xlims[1] <- 0
   }
-  if (!NAor0(DLM_data@Ref)) {
-    if (xlims[1] > DLM_data@Ref) 
-      xlims[1] <- max(0, 0.98 * DLM_data@Ref)
-    if (xlims[2] < DLM_data@Ref) 
-      xlims[2] <- 1.02 * DLM_data@Ref
-    if (xlims[2] > DLM_data@Ref * 2) 
-      xlims[2] <- 2 * DLM_data@Ref
+  if (!NAor0(Data@Ref)) {
+    if (xlims[1] > Data@Ref) 
+      xlims[1] <- max(0, 0.98 * Data@Ref)
+    if (xlims[2] < Data@Ref) 
+      xlims[2] <- 1.02 * Data@Ref
+    if (xlims[2] > Data@Ref * 2) 
+      xlims[2] <- 2 * Data@Ref
   }
   ylims <- c(0, 1)
   
   plot(NA, NA, xlim = xlims, ylim = ylims, main = "", xlab = "", ylab = "", 
     col = "white", lwd = 3, type = "l")
   abline(h = 0)
-  if (!NAor0(DLM_data@Ref)) {
-    abline(v = DLM_data@Ref, col = "light grey", lwd = 3)
-    if (!NAor0(DLM_data@Ref_type[1])) 
-      legend("bottomright", DLM_data@Ref_type, text.col = "grey", 
+  if (!NAor0(Data@Ref)) {
+    abline(v = Data@Ref, col = "light grey", lwd = 3)
+    if (!NAor0(Data@Ref_type[1])) 
+      legend("bottomright", Data@Ref_type, text.col = "grey", 
         bty = "n")
   }
   
   for (m in 1:nMPs) {
     
-    if (sum(!is.na(DLM_data@TAC[m, , 1])) > 10) {
+    if (sum(!is.na(Data@TAC[m, , 1])) > 10) {
       # only plot if there are sufficient non-NA TAC samples
-      x <- density(DLM_data@TAC[m, , 1], from = 0, na.rm = T)$x
-      y <- density(DLM_data@TAC[m, , 1], from = 0, na.rm = T)$y
+      x <- density(Data@TAC[m, , 1], from = 0, na.rm = T)$x
+      y <- density(Data@TAC[m, , 1], from = 0, na.rm = T)$y
       y <- y/max(y)
       lines(x, y, col = cols[m])
     } else {
@@ -157,7 +157,7 @@ plotOFL <- function(DLM_data, xlims = NA, perc = 0.5) {
         sep = ""))
     }
     if (!is.na(perc[1])) 
-      abline(v = quantile(DLM_data@TAC[m, , 1], p = perc, na.rm = T), 
+      abline(v = quantile(Data@TAC[m, , 1], p = perc, na.rm = T), 
         col = cols[m], lty = 2)
   }
   
@@ -165,19 +165,19 @@ plotOFL <- function(DLM_data, xlims = NA, perc = 0.5) {
   legend("topright", funcs, text.col = cols[cind], col = cols[cind], 
     lty = 1, bty = "n", cex = 0.75)
   
-  mtext(paste("OFL (", DLM_data@Units, ")", sep = ""), 1, outer = F, 
+  mtext(paste("OFL (", Data@Units, ")", sep = ""), 1, outer = F, 
     line = 2.6)
   mtext(paste("Standardized relative frequency", sep = ""), 2, outer = F, 
     line = 2.6)
   # mtext(paste('OFL calculation for
-  # ',DLM_data@Name,sep=''),3,outer=F,line=1)
+  # ',Data@Name,sep=''),3,outer=F,line=1)
   
 }
 
 # Primary functions
 
 
-#' What data-limited methods can be applied to this DLM_data object?
+#' What data-limited methods can be applied to this Data object?
 #' 
 #' An diagnostic tool that looks up the slot requirements of each method and
 #' compares this to the data available to limit the analysis to methods that
@@ -186,12 +186,12 @@ plotOFL <- function(DLM_data, xlims = NA, perc = 0.5) {
 #' samples) of a given method and is in units of seconds.
 #' 
 #' 
-#' @usage Can(DLM_data, timelimit = 1)
-#' @param DLM_data A data-limited methods data object (class DLM_data)
+#' @usage Can(Data, timelimit = 1)
+#' @param Data A data-limited methods data object (class Data)
 #' @param timelimit The maximum time (seconds) taken for a method to undertake
 #' 10 reps (this filters out methods that are too slow)
 #' @export Can
-Can <- function(DLM_data, timelimit = 1) DLMdiag(DLM_data, "available", 
+Can <- function(Data, timelimit = 1) DLMdiag(Data, "available", 
   timelimit = timelimit)
 
 
@@ -201,12 +201,12 @@ Can <- function(DLM_data, timelimit = 1) DLMdiag(DLM_data, "available",
 #' time along with a list of their data requirments.
 #' 
 #' 
-#' @usage Cant(DLM_data, timelimit = 1)
-#' @param DLM_data A data-limited methods data object (class DLM_data)
+#' @usage Cant(Data, timelimit = 1)
+#' @param Data A data-limited methods data object (class Data)
 #' @param timelimit The maximum time (seconds) taken for a method to undertake
 #' 10 reps (this filters out methods that are too slow)
 #' @export Cant
-Cant <- function(DLM_data, timelimit = 1) DLMdiag(DLM_data, "not available", 
+Cant <- function(Data, timelimit = 1) DLMdiag(Data, "not available", 
   timelimit = timelimit)
 
 
@@ -217,16 +217,16 @@ Cant <- function(DLM_data, timelimit = 1) DLMdiag(DLM_data, "not available",
 #' object
 #' 
 #' 
-#' @usage Needed(DLM_data, timelimit=1)
-#' @param DLM_data A data-limited methods data object
+#' @usage Needed(Data, timelimit=1)
+#' @param Data A data-limited methods data object
 #' @param timelimit The maximum time (seconds) taken to complete 10 reps
 #' @author T. Carruthers
 #' @export Needed
-Needed <- function(DLM_data, timelimit = 1) DLMdiag(DLM_data, "needed", 
+Needed <- function(Data, timelimit = 1) DLMdiag(Data, "needed", 
   timelimit = timelimit)
 
 # A function that determines the inputs for a given data-limited method
-# of class DLM_output and then analyses the sensitivity of TAC
+# of class Output and then analyses the sensitivity of TAC
 # estimates to marginal differences in each input.
 
 
@@ -234,13 +234,13 @@ Needed <- function(DLM_data, timelimit = 1) DLMdiag(DLM_data, "needed",
 #' Sensitivity analysis
 #' 
 #' A function that determines the inputs for a given data-limited method of
-#' class DLM_output and then analyses the sensitivity of TAC estimates to 
+#' class Output and then analyses the sensitivity of TAC estimates to 
 #' marginal differences in each input. The range used for sensitivity is based 
 #' on the user-specified CV for that input (e.g. CV_Mort, Mort)
 #' 
 #' 
-#' @usage Sense(DLM_data, MP, nsense = 6, reps = 100, perc = c(0.05, 0.5, 0.95), ploty = T)
-#' @param DLM_data A data-limited methods data object
+#' @usage Sense(Data, MP, nsense = 6, reps = 100, perc = c(0.05, 0.5, 0.95), ploty = T)
+#' @param Data A data-limited methods data object
 #' @param MP A character string representing an MP applied in calculating the TAC recommendations in the DLM object
 #' @param nsense The number of points over which to calculate the TAC (resolution)
 #' @param reps The number of samples of the quota taken for the calculation of the TAC
@@ -249,20 +249,20 @@ Needed <- function(DLM_data, timelimit = 1) DLMdiag(DLM_data, "needed",
 #'
 #' @author T. Carruthers
 #' @export Sense
-Sense <- function(DLM_data, MP, nsense = 6, reps = 100, perc = c(0.05, 
+Sense <- function(Data, MP, nsense = 6, reps = 100, perc = c(0.05, 
   0.5, 0.95), ploty = T) {
   
-  DLM_data2 <- DLM_data
+  DLM_data2 <- Data
   nm <- deparse(substitute(DLM_data2))
   refTAC <- quantile(getTAC(DLM_data2, MP, reps)[[1]], perc, na.rm = T)
   
-  DLM_data <- DLM_data2
+  Data <- DLM_data2
   reqs <- Required(MP)  #read.csv(paste(getwd(),'/Data/Data requirements.csv',sep=''),header=T)
   ind <- (1:nrow(reqs))[reqs[, match(MP, names(reqs))] == "Y"]
   # for(i in 1:length(reqs))
   
   
-  slotsCV <- slotNames("DLM_data")[grep("CV_", slotNames("DLM_data"))]
+  slotsCV <- slotNames("Data")[grep("CV_", slotNames("Data"))]
   slots <- rep("", length(slotsCV))
   for (i in 1:length(slotsCV)) slots[i] <- substr(slotsCV[i], 4, nchar(slotsCV[i]))
   
@@ -273,35 +273,35 @@ Sense <- function(DLM_data, MP, nsense = 6, reps = 100, perc = c(0.05,
   nslots <- length(slots)
   
   nrep <- nslots * nsense
-  DLM_data <- replic8(DLM_data, nrep)
+  Data <- replic8(Data, nrep)
   pss <- seq(0, 1, length.out = nsense + 2)[2:(nsense + 1)]
   vals <- array(NA, dim = c(nslots, nsense))
   
   for (i in 1:nslots) {
     ind <- (((i - 1) * nsense + 1):(i * nsense))
-    mn <- attr(DLM_data, slots[i])[1]
-    cv <- attr(DLM_data, slotsCV[i])[1] * 2  # twice the CV of the variable specified in the DLM object
-    if (class(attr(DLM_data, slots[i])) == "numeric") {
+    mn <- attr(Data, slots[i])[1]
+    cv <- attr(Data, slotsCV[i])[1] * 2  # twice the CV of the variable specified in the DLM object
+    if (class(attr(Data, slots[i])) == "numeric") {
       if (mn > 0) {
-        attr(DLM_data, slots[i])[ind] <- qlnorm(pss, mconv(mn, 
+        attr(Data, slots[i])[ind] <- qlnorm(pss, mconv(mn, 
           cv * mn), sdconv(mn, cv * mn))
         vals[i, ] <- qlnorm(pss, mconv(mn, cv * mn), sdconv(mn, 
           cv * mn))
       } else {
-        attr(DLM_data, slots[i])[ind] <- -qlnorm(pss, mconv(-mn, 
+        attr(Data, slots[i])[ind] <- -qlnorm(pss, mconv(-mn, 
           cv * -mn), sdconv(-mn, cv * -mn))
         vals[i, ] <- -qlnorm(pss, mconv(-mn, cv * -mn), sdconv(-mn, 
           cv * -mn))
       }
     } else {
-      cv <- attr(DLM_data, slotsCV[i])[1]
-      attr(DLM_data, slots[i])[ind, ] <- attr(DLM_data, slots[i])[ind, 
+      cv <- attr(Data, slotsCV[i])[1]
+      attr(Data, slots[i])[ind, ] <- attr(Data, slots[i])[ind, 
         ] * qlnorm(pss, mconv(1, cv), sdconv(1, cv))
       vals[i, ] <- qlnorm(pss, mconv(1, cv), sdconv(1, cv))
     }
   }
   
-  TACa <- getTAC(DLM_data, MPs = MP, reps = reps)[[1]]
+  TACa <- getTAC(Data, MPs = MP, reps = reps)[[1]]
   TACa <- apply(TACa, 3, quantile, p = perc, na.rm = T)
   LB <- ((1:nslots) - 1) * 4 + 1
   UB <- (1:nslots) * 4
@@ -338,10 +338,10 @@ Sense <- function(DLM_data, MP, nsense = 6, reps = 100, perc = c(0.05,
       legend("top", legend = sname[i], text.col = "blue", bty = "n")
     }
     
-    mtext(paste("Output control (", DLM_data@Units, ")", sep = ""), 
+    mtext(paste("Output control (", Data@Units, ")", sep = ""), 
       2, outer = T, line = 0.5)
     mtext("Parameter / variable input level", 1, outer = T, line = 0.5)
-    mtext(paste("Sensitivity analysis for ", DLM_data@Name, ": ", MP, 
+    mtext(paste("Sensitivity analysis for ", Data@Name, ": ", MP, 
       sep = ""), 3, outer = T, line = 0.5)
   }
   # assign(nm,DLM2,envir=.GlobalEnv)
@@ -358,97 +358,97 @@ Sense <- function(DLM_data, MP, nsense = 6, reps = 100, perc = c(0.05,
 #' Replicates position 1 data to multiple positions for sensitivity testing etc
 #' 
 #' 
-#' @usage replic8(DLM_data, nrep)
-#' @param DLM_data A data-limited methods data object
+#' @usage replic8(Data, nrep)
+#' @param Data A data-limited methods data object
 #' @param nrep The number of positions to expand the DLM object to
 #' @author T. Carruthers
 #' @export replic8
-replic8 <- function(DLM_data, nrep) {
+replic8 <- function(Data, nrep) {
   
-  slotnam <- slotNames(DLM_data)
+  slotnam <- slotNames(Data)
   slotnam <- slotnam[slotnam != "Ref" & slotnam != "OM" & slotnam != 
     "MaxAge" & slotnam != "CAL_bins" & slotnam != "Year"]
   
   for (sl in 1:length(slotnam)) {
-    slt <- attr(DLM_data, slotnam[sl])
+    slt <- attr(Data, slotnam[sl])
     if (class(slt) == "matrix") {
-      attr(DLM_data, slotnam[sl]) <- matrix(rep(slt, each = nrep), 
+      attr(Data, slotnam[sl]) <- matrix(rep(slt, each = nrep), 
         nrow = nrep, ncol = ncol(slt))
     } else if (class(slt) == "numeric") {
-      attr(DLM_data, slotnam[sl]) <- rep(slt, nrep)
+      attr(Data, slotnam[sl]) <- rep(slt, nrep)
     } else if (class(slt) == "array") {
-      attr(DLM_data, slotnam[sl]) <- array(rep(slt, each = nrep), 
+      attr(Data, slotnam[sl]) <- array(rep(slt, each = nrep), 
         dim = c(nrep, dim(slt)[2:3]))
     }
   }
-  DLM_data
+  Data
 }
 
 # A function that returns the stochastic TAC recommendations from a
-# vector of data-limited MPs (DLM_output) given a data-limited data
-# object DLM_data
+# vector of data-limited MPs (Output) given a data-limited data
+# object Data
 
 
 #' Calculate TAC recommendations for more than one MP
 #' 
 #' A function that returns the stochastic TAC recommendations from a vector of
-#' data-limited MPs (DLM_output) given a data-limited data object DLM_data
+#' data-limited MPs (Output) given a data-limited data object Data
 #' 
 #' 
-#' @usage TAC(DLM_data, MPs = NA, reps = 100, timelimit = 1)
-#' @param DLM_data A data-limited methods data object
+#' @usage TAC(Data, MPs = NA, reps = 100, timelimit = 1)
+#' @param Data A data-limited methods data object
 #' @param MPs optional vector of MP names
 #' @param reps Number of repititions
 #' @param timelimit The maximum time (seconds) taken to complete 10 reps
 #' @author T. Carruthers
 #' @export TAC
-TAC <- function(DLM_data, MPs = NA, reps = 100, timelimit = 1) {
+TAC <- function(Data, MPs = NA, reps = 100, timelimit = 1) {
   
-  nm <- deparse(substitute(DLM_data))
-  PosMPs <- Can(DLM_data, timelimit = timelimit)
-  PosMPs <- PosMPs[PosMPs %in% avail("DLM_output")]
-  DLM_data@PosMPs <- PosMPs
+  nm <- deparse(substitute(Data))
+  PosMPs <- Can(Data, timelimit = timelimit)
+  PosMPs <- PosMPs[PosMPs %in% avail("Output")]
+  Data@PosMPs <- PosMPs
   if (!is.na(MPs[1])) 
-    DLM_data@MPs <- MPs[MPs %in% PosMPs]
+    Data@MPs <- MPs[MPs %in% PosMPs]
   if (is.na(MPs[1])) 
-    DLM_data@MPs <- PosMPs
-  funcs <- DLM_data@MPs
+    Data@MPs <- PosMPs
+  funcs <- Data@MPs
   
   if (length(funcs) == 0) {
     stop("None of the methods 'MPs' are possible given the data available")
   } else {
-    temp <- getTAC(DLM_data, MPs = funcs, reps)
+    temp <- getTAC(Data, MPs = funcs, reps)
     TACa <- temp[[1]]
-    DLM_data <- temp[[2]]
-    DLM_data@TAC <- TACa
-    return(DLM_data)
+    Data <- temp[[2]]
+    Data@TAC <- TACa
+    return(Data)
     # assign(nm,DLM,envir=.GlobalEnv)
   }
   
 }
 
-getTAC <- function(DLM_data, MPs = NA, reps = 100) {
+getTAC <- function(Data, MPs = NA, reps = 100) {
   
-  nsims <- length(DLM_data@Mort)
+  nsims <- length(Data@Mort)
   nMPs <- length(MPs)
   TACa <- array(NA, dim = c(nMPs, reps, nsims))
   
-  if (!sfIsRunning() | (nMPs < 8 & nsims < 8)) {
+  if (!sfIsRunning()) {
     for (ff in 1:nMPs) {
-      temp <- sapply(1:nsims, MPs[ff], DLM_data = DLM_data, reps = reps)
+      temp <- sapply(1:nsims, MPs[ff], Data = Data, reps = reps)
       if (mode(temp) == "numeric") 
         TACa[ff, , ] <- temp
       if (mode(temp) == "list") {
         TACa[ff, , ] <- unlist(temp[1, ])
-        for (x in 1:nsims) DLM_data@Misc[[x]] <- temp[2, x][[1]]
+        for (x in 1:nsims) Data@Misc[[x]] <- temp[2, x][[1]]
       }
     }
   } else {
-    sfExport(list = c("DLM_data"))
+    sfExport("Data") #####
     if (nsims < 8) {
       sfExport(list = c("MPs", "reps"))
       for (ss in 1:nsims) {
-        temp <- (sfSapply(1:length(MPs), parallelMPs, DLM_data = DLM_data, 
+        temp <- (sfSapply(1:length(MPs), parallelMPs, Data = Data, 
           reps = reps, MPs = MPs, ss = ss))
         if (mode(temp) == "list") {
           Lens <- unlist(lapply(temp, length))
@@ -462,7 +462,7 @@ getTAC <- function(DLM_data, MPs = NA, reps = 100) {
             ind <- which(Classes == "list")
             TACa[X, , ss] <- unlist(temp[, X][[1]][1:(ind - 1), 
             ])
-            DLM_data@Misc[[ss]] <- temp[, X][[1]][ind, ]
+            Data@Misc[[ss]] <- temp[, X][[1]][ind, ]
           }
           }
         } else {
@@ -472,13 +472,13 @@ getTAC <- function(DLM_data, MPs = NA, reps = 100) {
       }
     } else {
       for (ff in 1:nMPs) {
-        temp <- sfSapply(1:nsims, MPs[ff], DLM_data = DLM_data, 
+        temp <- sfSapply(1:nsims, MPs[ff], Data = Data, 
           reps = reps)
         if (mode(temp) == "numeric") 
           TACa[ff, , ] <- temp
         if (mode(temp) == "list") {
           TACa[ff, , ] <- unlist(temp[1, ])
-          for (x in 1:nsims) DLM_data@Misc[[x]] <- temp[2, x][[1]]
+          for (x in 1:nsims) Data@Misc[[x]] <- temp[2, x][[1]]
         }
       }
     }
@@ -490,7 +490,7 @@ getTAC <- function(DLM_data, MPs = NA, reps = 100) {
         sep = ""))
     }
   }
-  out <- list(TACa, DLM_data)
+  out <- list(TACa, Data)
   return(out)
 }
 
@@ -502,60 +502,60 @@ getTAC <- function(DLM_data, MPs = NA, reps = 100) {
 #' of DLM quota has been specified
 #' 
 #' 
-#' @usage Sam(DLM_data, MPs = NA, reps = 100, perc = 0.5)
-#' @param DLM_data A data-limited methods data object
+#' @usage Sam(Data, MPs = NA, reps = 100, perc = 0.5)
+#' @param Data A data-limited methods data object
 #' @param MPs A character vector of methods of DLM quota, DLM space or DLM size
 #' @param reps The number of samples of quota recommendations by method
 #' @param perc quantile of the recommendation to use
 #' @author T. Carruthers
 #' @export Sam
-Sam <- function(DLM_data, MPs = NA, reps = 100, perc = 0.5) {
+Sam <- function(Data, MPs = NA, reps = 100, perc = 0.5) {
   nm <- deparse(substitute(DLM))
-  DLM_data@PosMPs <- MPs
-  funcs <- DLM_data@PosMPs
+  Data@PosMPs <- MPs
+  funcs <- Data@PosMPs
   nMPs <- length(funcs)
-  DLM_data@MPs <- funcs
-  temp <- getTAC(DLM_data, MPs = funcs, reps)
+  Data@MPs <- funcs
+  temp <- getTAC(Data, MPs = funcs, reps)
   TACa <- temp[[1]]
-  DLM_data <- temp[[2]]
-  nsim <- length(DLM_data@Mort)
-  ref <- array(rep(DLM_data@Ref, nMPs), c(nsim, nMPs))
+  Data <- temp[[2]]
+  nsim <- length(Data@Mort)
+  ref <- array(rep(Data@Ref, nMPs), c(nsim, nMPs))
   TACm <- apply(TACa, c(3, 1), quantile, p = perc, na.rm = T)
   TACbias <- (TACm - ref)/ref * 100
-  POF <- round(apply(TACbias > 0, 2, sum)/length(DLM_data@Mort) * 100, 
+  POF <- round(apply(TACbias > 0, 2, sum)/length(Data@Mort) * 100, 
     1)
-  DLM_data@TAC <- TACa
-  DLM_data@TACbias <- TACbias
-  DLM_data
+  Data@TAC <- TACa
+  Data@TACbias <- TACbias
+  Data
 }
 
 
 # Input Control Functions Wrapper function for input control methods
 
 
-#' Runs input control MPs on a DLM_data object.
+#' Runs input control MPs on a Data object.
 #' 
-#' Function runs a MP (or MPs) of class 'DLM_input' and returns a list: input
-#' control recommendation(s) in element 1 and DLM_data object in element 2.
+#' Function runs a MP (or MPs) of class 'Input' and returns a list: input
+#' control recommendation(s) in element 1 and Data object in element 2.
 #' 
 #' 
-#' @usage runInMP(DLM_data, MPs = NA, reps = 100)
-#' @param DLM_data A object of class DLM_data
-#' @param MPs A vector of MPs of class 'DLM_input'
+#' @usage runInMP(Data, MPs = NA, reps = 100)
+#' @param Data A object of class Data
+#' @param MPs A vector of MPs of class 'Input'
 #' @param reps Number of stochastic repititions - often not used in input
 #' control MPs.
 #' @author A. Hordyk
 #' @export runInMP
-runInMP <- function(DLM_data, MPs = NA, reps = 100) {
+runInMP <- function(Data, MPs = NA, reps = 100) {
   
-  nsims <- length(DLM_data@Mort)
+  nsims <- length(Data@Mort)
   nMPs <- length(MPs)
-  # len <- 4 + DLM_data@MaxAge
+  # len <- 4 + Data@MaxAge
   len <- 8
   InC <- array(NA, dim = c(len, nsims, nMPs))
   if (!sfIsRunning() | (nMPs < 8 & nsims < 8)) {
     for (ff in 1:nMPs) {
-      temp <- sapply(1:nsims, MPs[ff], DLM_data = DLM_data, reps = reps)
+      temp <- sapply(1:nsims, MPs[ff], Data = Data, reps = reps)
       if (mode(temp) == "numeric") {
         Nrow <- nrow(temp)
         if (Nrow < len) {
@@ -573,15 +573,15 @@ runInMP <- function(DLM_data, MPs = NA, reps = 100) {
           temp2 <- rbind(temp2, matrix(NA, nrow = dif, ncol = ncol(temp2)))
         }
         InC[, , ff] <- temp2
-        for (x in 1:nsims) DLM_data@Misc[[x]] <- temp[2, x][[1]]
+        for (x in 1:nsims) Data@Misc[[x]] <- temp[2, x][[1]]
       }
     }
   } else {
-    sfExport(list = c("DLM_data"))
+    sfExport(list = c("Data"))
     if (nsims < 8) {
       sfExport(list = c("MPs", "reps"))
       for (ss in 1:nsims) {
-        temp <- t(sfSapply(1:length(MPs), parallelMPs, DLM_data = DLM_data, 
+        temp <- t(sfSapply(1:length(MPs), parallelMPs, Data = Data, 
           reps = reps, MPs = MPs, ss = ss))
         if (mode(temp) == "numeric") {
           Nrow <- nrow(temp)
@@ -604,7 +604,7 @@ runInMP <- function(DLM_data, MPs = NA, reps = 100) {
             temp2 <- rbind(temp2, matrix(NA, nrow = dif, ncol = ncol(temp2)))
             }
             InC[, ss, X] <- temp2
-            DLM_data@Misc[[ss]] <- temp[[1]][2, X][[1]]
+            Data@Misc[[ss]] <- temp[[1]][2, X][[1]]
           } else {
             InC[, ss, X] <- unlist(temp[, X])
           }
@@ -613,7 +613,7 @@ runInMP <- function(DLM_data, MPs = NA, reps = 100) {
       }
     } else {
       for (ff in 1:nMPs) {
-        temp <- sfSapply(1:nsims, MPs[ff], DLM_data = DLM_data, 
+        temp <- sfSapply(1:nsims, MPs[ff], Data = Data, 
           reps = reps)
         if (mode(temp) == "numeric") {
           Nrow <- nrow(temp)
@@ -632,13 +632,13 @@ runInMP <- function(DLM_data, MPs = NA, reps = 100) {
           temp2 <- rbind(temp2, matrix(NA, nrow = dif, ncol = ncol(temp2)))
           }
           InC[, , ff] <- temp2
-          for (x in 1:nsims) DLM_data@Misc[[x]] <- temp[2, x][[1]]
+          for (x in 1:nsims) Data@Misc[[x]] <- temp[2, x][[1]]
         }
       }
     }
   }
   
-  out <- list(InC, DLM_data)
+  out <- list(InC, Data)
   return(out)
 }
 
@@ -652,12 +652,12 @@ runInMP <- function(DLM_data, MPs = NA, reps = 100) {
 #' @return Returns a data frame containing the information shown in the plot
 #' @author A. Hordyk
 #' @export
-boxplot.DLM_data <- function(x, outline = FALSE, ...) {
-  DLM_data <- x
-  if (class(DLM_data) != "DLM_data") 
-    stop("Object must be of class 'DLM_data'")
-  tacs <- t(DLM_data@TAC[, , 1])
-  MPs <- DLM_data@MPs
+boxplot.Data <- function(x, outline = FALSE, ...) {
+  Data <- x
+  if (class(Data) != "Data") 
+    stop("Object must be of class 'Data'")
+  tacs <- t(Data@TAC[, , 1])
+  MPs <- Data@MPs
   ind <- grep("ref", MPs)
   if (length(ind) > 0) {
     tacs <- tacs[, -ind]
@@ -687,13 +687,13 @@ boxplot.DLM_data <- function(x, outline = FALSE, ...) {
   boxplot(tacs, names = MPs, las = 1, col = cols, outline = outline, 
     frame = FALSE, ylim = ylim, horizontal = TRUE, ...)
   
-  mtext(paste("TAC (", DLM_data@Units, ")", sep = ""), side = 1, outer = T, 
+  mtext(paste("TAC (", Data@Units, ")", sep = ""), side = 1, outer = T, 
     line = 0.5, cex = 1.25)
   mtext(side = 2, "Management Procedures", outer = TRUE, line = 3, cex = 1.25)
-  mtext(paste("TAC calculation for ", DLM_data@Name, sep = ""), 3, outer = T, 
+  mtext(paste("TAC calculation for ", Data@Name, sep = ""), 3, outer = T, 
     line = -0.5, cex = 1.25)
   
-  data.frame(MP = MPs, Median = Median, SD = SD, Units = DLM_data@Units)
+  data.frame(MP = MPs, Median = Median, SD = SD, Units = Data@Units)
   
 }
 
@@ -702,28 +702,28 @@ boxplot.DLM_data <- function(x, outline = FALSE, ...) {
 #' Runs a set of input control methods are returns the output in a single table
 #' 
 #' 
-#' @usage Input(DLM_data, MPs = NA, reps = 100, timelimit = 10, CheckMPs =
+#' @usage Input(Data, MPs = NA, reps = 100, timelimit = 10, CheckMPs =
 #' TRUE)
-#' @param DLM_data A DLM_data object
+#' @param Data A Data object
 #' @param MPs A list of input MPs, if NA all available input MPs are run
 #' @param reps Number of repetitions (for those methods that use them)
 #' @param timelimit Maximum timelimit to run MP (in seconds)
 #' @param CheckMPs Logical, the Can function is run if this is TRUE
 #' @author A. Hordyk
 #' @export Input
-Input <- function(DLM_data, MPs = NA, reps = 100, timelimit = 10, CheckMPs = TRUE) {
+Input <- function(Data, MPs = NA, reps = 100, timelimit = 10, CheckMPs = TRUE) {
   print("Checking which MPs can be run")
   flush.console()
   if (CheckMPs) 
-    PosMPs <- Can(DLM_data, timelimit = timelimit)
+    PosMPs <- Can(Data, timelimit = timelimit)
   if (!CheckMPs) 
     PosMPs <- MPs
-  PosMPs <- PosMPs[PosMPs %in% avail("DLM_input")]
+  PosMPs <- PosMPs[PosMPs %in% avail("Input")]
   if (!is.na(MPs[1])) 
-    DLM_data@MPs <- MPs[MPs %in% PosMPs]
+    Data@MPs <- MPs[MPs %in% PosMPs]
   if (is.na(MPs[1])) 
-    DLM_data@MPs <- PosMPs
-  funcs <- DLM_data@MPs
+    Data@MPs <- PosMPs
+  funcs <- Data@MPs
   
   if (length(funcs) == 0) {
     stop("None of the methods 'MPs' are possible given the data available")
@@ -735,7 +735,7 @@ Input <- function(DLM_data, MPs = NA, reps = 100, timelimit = 10, CheckMPs = TRU
     for (mm in 1:length(funcs)) {
       print(paste("Running", mm, "of", length(funcs), "-", funcs[mm]))
       flush.console()
-      runIn <- runInMP(DLM_data, MPs = funcs[mm], reps = reps)[[1]][, 
+      runIn <- runInMP(Data, MPs = funcs[mm], reps = reps)[[1]][, 
         , 1]
       Out[mm, ] <- runIn[2:7]
       Out[, 4:6] <- round(Out[, 4:6], 2)
