@@ -11,6 +11,7 @@
 #' @importFrom parallel detectCores
 #' @export 
 setup <- function(cpus=parallel::detectCores()) {
+  if(snowfall::sfIsRunning()) snowfall::sfStop()
   snowfall::sfInit(parallel=TRUE,cpus=cpus)  
 }
 
@@ -25,9 +26,14 @@ setup <- function(cpus=parallel::detectCores()) {
 #' @author T. Carruthers
 #' @export avail
 avail <- function(classy) {
-  return(unique(c(ls("package:DLMtool")[unlist(lapply(ls("package:DLMtool"), 
+ temp <- try(class(classy), silent=TRUE)
+  if (class(temp) == "try-error") classy <- deparse(substitute(classy))
+  temp <- unique(c(ls("package:DLMtool")[unlist(lapply(ls("package:DLMtool"), 
     getclass, classy = classy))], ls(envir = .GlobalEnv)[unlist(lapply(ls(envir = .GlobalEnv), 
-    getclass, classy = classy))])))
+    getclass, classy = classy))])) 
+   if (classy == "Observation") message("Class 'Observation' has been re-named 'Obs'")	
+   if (length(temp) <1) stop("No objects of class '", classy, "' found", call.=FALSE)
+  return(temp)
 }
 
 #' get object class
@@ -43,7 +49,6 @@ avail <- function(classy) {
 #' @export getclass
 getclass <- function(x, classy) inherits(get(x), classy)
 
-
 #' What methods need what data
 #' 
 #' A function that finds all methods in the environment and searches the
@@ -57,9 +62,9 @@ getclass <- function(x, classy) inherits(get(x), classy)
 #' @export Required
 Required <- function(funcs = NA) {
   if (is.na(funcs[1])) 
-    funcs <- c(avail("DLM_output"), avail("DLM_input"))
-  slots <- slotNames("DLM_data")
-  slotnams <- paste("DLM_data@", slotNames("DLM_data"), sep = "")
+    funcs <- c(avail("Output"), avail("Input"))
+  slots <- slotNames("Data")
+  slotnams <- paste("Data@", slotNames("Data"), sep = "")
   repp <- rep("", length(funcs))
   
   for (i in 1:length(funcs)) {
@@ -91,11 +96,9 @@ Required <- function(funcs = NA) {
 #' @export DLMDataDir
 DLMDataDir <- function(stock = NA) {
   if (is.na(stock)) {
-    return(paste(searchpaths()[match("package:DLMtool", search())], 
-      "/", sep = ""))
+    return(paste(searchpaths()[match("package:DLMtool", search())], "/", sep = ""))
   } else {
-    return(paste(searchpaths()[match("package:DLMtool", search())], 
-      "/", stock, ".csv", sep = ""))
+    return(paste(searchpaths()[match("package:DLMtool", search())], "/", stock, ".csv", sep = ""))
   }
 }
 
@@ -107,7 +110,7 @@ DLMDataDir <- function(stock = NA) {
 #' 
 #' 
 #' @usage Fease(feaseobj,outy='table')
-#' @param feaseobj An object of class 'DLM_fease'
+#' @param feaseobj An object of class 'Fease'
 #' @param outy Determines whether you would like a full table or some column of
 #' the table for a specific case of the feasibility object. When set equal to
 #' table, the full table is produced. When set equal to an integer number the
@@ -116,8 +119,8 @@ DLMDataDir <- function(stock = NA) {
 #' @export Fease
 Fease <- function(feaseobj, outy = "table") {
   
-  if (class(feaseobj) != "DLM_fease") 
-    stop("Incorrect format: you need an object of class DLM_fease")
+  if (class(feaseobj) != "Fease") 
+    stop("Incorrect format: you need an object of class Fease")
   
   sloty <- c("Cat", "Ind", "AvC", "Dt", "Rec", "CAA", "CAL", "Mort", 
     "L50", "L95", "vbK", "vbLinf", "vbt0", "wla", "wlb", "steep", "LFC", 
@@ -359,7 +362,7 @@ getq <- function(x, dep, Find, Perr, Marray, hs, Mat_age, Wt_age, R0, V,
 #' @author T. Carruthers
 getq2 <- function(x, dep, Find, Perr, Marray, hs, Mat_age, Wt_age, R0, V, 
   nyears, maxage, mov, Spat_targ, SRrel, aR, bR) {
-  opt <- optimize(optQ_cpp, log(c(0.0075, 15)), depc = dep[x], Fc = Find[x, ], 
+  opt <- optimize(optQ_cpp, log(c(0.00001, 15)), depc = dep[x], Fc = Find[x, ], 
     Perrc = Perr[x, ], Mc = Marray[x, ], hc = hs[x], Mac = Mat_age[x, ], 
     Wac = Wt_age[x, , ], R0c = R0[x], Vc = V[x, , ], nyears = nyears, 
 	maxage = maxage, movc = mov[x, , ], Spat_targc = Spat_targ[x], 
@@ -817,8 +820,7 @@ SetRecruitCycle <- function(x = 1, Period, Amplitude, TotYears, Shape = c("sin",
 makePerf <- function(OMin, except = NULL) {
   nms <- slotNames(OMin)
   # exceptions
-  if (is.null(except)) 
-    except <- "EVERYTHING"
+  if (is.null(except)) except <- "EVERYTHING"
   exclude <- unique(grep(paste(except, collapse = "|"), nms, value = FALSE))
   
   vars <- c("grad", "cv", "sd", "inc")
@@ -826,6 +828,7 @@ makePerf <- function(OMin, except = NULL) {
   ind <- ind[(!(nms[ind] %in% exclude))]
   for (X in seq_along(ind)) {
     n <- length(slot(OMin, nms[ind[X]]))
+    if (n == 0) n <- 2
     slot(OMin, nms[ind[X]]) <- rep(0, n)
   }
   
@@ -857,10 +860,10 @@ makePerf <- function(OMin, except = NULL) {
 #' Print out plotting functions
 #' 
 #' This function prints out the available plotting functions for objects of
-#' class MSE or DLM_data
+#' class MSE or Data
 #' 
 #' 
-#' @usage plotFun(class = c('MSE', 'DLM_data'), msg=TRUE)
+#' @usage plotFun(class = c('MSE', 'Data'), msg=TRUE)
 #' @param class Character string. Prints out the plotting functions for objects
 #' of this class.
 #' @param msg Logical. Should the functions be printed to screen?
@@ -869,7 +872,7 @@ makePerf <- function(OMin, except = NULL) {
 #' functions are missed. Let us know if you find any and we will add them.
 #' @author A. Hordyk
 #' @export plotFun
-plotFun <- function(class = c("MSE", "DLM_data"), msg = TRUE) {
+plotFun <- function(class = c("MSE", "Data"), msg = TRUE) {
   class <- match.arg(class)
   tt <- lsf.str("package:DLMtool")
   p <- p2 <- rep(FALSE, length(tt))
@@ -885,12 +888,13 @@ plotFun <- function(class = c("MSE", "DLM_data"), msg = TRUE) {
     message("DLMtool functions for plotting objects of class ", class, 
       " are:")
   out <- sort(tt[which(p & p2)])
-  out <- out[-grep("plotFun", out)]
+  if (any(grepl("plotFun", out))) out <- out[-grep("plotFun", out)]
+  if (any(grepl("plot.OM", out))) out <- out[-grep("plot.OM", out)]
   if (class == "MSE") {
     out <- c(out, "barplot", "boxplot", "VOI", "VOI2")
     out <- sort(out)
   }
-  if (class == "DLM_data") {
+  if (class == "Data") {
     out <- c(out, "boxplot", "Sense")
     out <- sort(out)
   }
