@@ -362,7 +362,7 @@ getFref2 <- function(x, Marray, Wt_age, Mat_age, Perr, N_s, SSN_s, Biomass_s,
     	
     opt <- optimize(doprojPI_cpp, log(c(0.001, 5)), Mvec = Marray[x, (nyears + 1):(nyears + proyears)], 
 	  Wac = Wt_age[x, , (nyears + 1):(nyears + proyears)], Mac = Mat_age[x, ], 
-	    Pc = Perr[x, (nyears + 1):(nyears + proyears)], N_c = N_s[x, , 1,], 
+	    Pc = Perr[x, (maxage+nyears):(maxage-1+nyears + proyears)], N_c = N_s[x, , 1,], 
 		SSN_c = SSN_s[x, , 1, ], Biomass_c = Biomass_s[x, , 1, ], 
 		VBiomass_c = VBiomass_s[x, , 1, ], SSB_c = SSB_s[x, , 1, ], Vc = Vn[x, , ], 
 		hc = hs[x], R0ac = R0a[x, ], proyears, nareas, maxage, movc = mov[x, , ], 
